<?php 

add_action( 'admin_menu', 'ypf_add_options_page' );

function ypf_add_options_page() {
	add_options_page( 'Youtube Profile Field Options', 'Youtube Profile Field', 'manage_options', 'youtube-profile-field', 'ypf_plugin_options' );
}

// Option page
function ypf_plugin_options() { ?>

	<div class="wrap">
		<?php screen_icon(); ?>
		<h2><?php _e( 'Youtube Profile Field Options', 'youtubeprofile' ); ?></h2>

		<form action="options.php" method="post">
			<?php settings_fields( 'ypf_options' ); ?>
			<?php do_settings_sections( 'ypf_options' ); ?>
			<?php submit_button(); ?>
		</form>

	</div>
    
	<?php
}

// Register and define the settings
add_action( 'admin_init', 'ypf_admin_init' );

function ypf_admin_init() {

	register_setting( 'ypf_options', 'ypf_options', 'ypf_validate_options' );

	add_settings_section(
		'ypf_options_main',
		__( 'Settings', 'youtubeprofile' ),
		'ypf_section_text',
		'ypf_options'
	);

	add_settings_field(
		'ypf_count',
		__( 'Videos to show', 'youtubeprofile' ),
		'ypf_setting_input_number',
		'ypf_options',
		'ypf_options_main'
	);

	add_settings_field(
		'ypf_embed_code',
		__( 'Use old embed code', 'youtubeprofile' ),
		'ypf_setting_embed_code',
		'ypf_options',
		'ypf_options_main'
	);

	add_settings_field(
		'ypf_heading_start',
		__( 'Heading to titles', 'youtubeprofile' ),
		'ypf_setting_input_heading_start',
		'ypf_options',
		'ypf_options_main'
	);

	add_settings_field(
		'ypf_heading_end',
		__( 'End heading', 'youtubeprofile' ),
		'ypf_setting_input_heading_end',
		'ypf_options',
		'ypf_options_main'
	);

	add_settings_field(
		'ypf_width',
		__( 'Width', 'youtubeprofile' ),
		'ypf_setting_input_width',
		'ypf_options',
		'ypf_options_main'
	);

	add_settings_field(
		'ypf_height',
		__( 'Height', 'youtubeprofile' ),
		'ypf_setting_input_height',
		'ypf_options',
		'ypf_options_main'
	);

	add_settings_section(
		'ypf_options_help',
		__( 'Help', 'youtubeprofile' ),
		'ypf_section_help',
		'ypf_options'
	);
}

// Settings section
function ypf_section_text() {
	return;
}

// "Number of videos" text field
function ypf_setting_input_number() {
	$options = get_option( 'ypf_options' );
	$text_string = $options['count'];

	echo "<input id='ypf_count' name='ypf_options[count]' type='text' value='$text_string' /> ";
	_e( 'Number of videos you want to show (Can be overriden with a template tag or shortcode)', 'youtubeprofile' );
}

// Embed code
function ypf_setting_embed_code() {
	$options = get_option( 'ypf_options' ); ?>

	<input id="ypf_embed_code" name="ypf_options[embed_code]" type="checkbox" value="1" <?php checked( '1', $options['embed_code'] ); ?> /> &nbsp;&nbsp;&nbsp; <?php

	_e( 'There are two styles of embed codes that are available for YouTube videos. The new embed code begins with "&lt;iframe..." and supports both Flash and HTML5 video. The older style of embed code begins with "&lt;object..." and only support Flash playback.', 'youtubeprofile' );
}

// Heading start field
function ypf_setting_input_heading_start() {
	$options = get_option( 'ypf_options' );
	$text_string = $options['headingStart'];

	echo "<input id='ypf_setting_input_heading_start' name='ypf_options[headingStart]' type='text' value='$text_string' /> ";
	_e( '&lt;h3&gt;, &lt;p&gt; or something else. Leave empty to hide titles', 'youtubeprofile' );
}

// Heading end field
function ypf_setting_input_heading_end() {
	$options = get_option( 'ypf_options' );
	$text_string = $options['headingEnd'];

	echo "<input id='ypf_setting_input_heading_end' name='ypf_options[headingEnd]' type='text' value='$text_string' /> ";
	echo '&lt;/h3&gt;, &lt;/p&gt;';
}

// Width field
function ypf_setting_input_width() {
	$options = get_option( 'ypf_options' );
	$text_string = $options['width'];

	echo "<input id='ypf_width' name='ypf_options[width]' type='text' value='$text_string' /> ";
	_e( 'If left blank, the width of the videos will default to your media settings.', 'youtubeprofile' );
}

// Height field
function ypf_setting_input_height() {
	$options = get_option( 'ypf_options' );
	$text_string = $options['height'];

	echo "<input id='ypf_height' name='ypf_options[height]' type='text' value='$text_string' /> ";
	_e( 'If left blank, the height of the videos will default to your media settings.', 'youtubeprofile' );
}

// Validate user input 
function ypf_validate_options( $input ) {

	$input['count'] = intval( $input['count'] );
	$input['width'] = intval( $input['width'] );
	$input['height'] = intval( $input['height'] );

	$input['embed_code'] = ( $input['embed_code'] == 1 ? 1 : 0 );

	$input['headingStart'] = wp_kses_data( esc_html( $input['headingStart'] ) );
	$input['headingEnd'] = wp_kses_data( esc_html( $input['headingEnd'] ) );

	return $input;
}

// Help section
function ypf_section_help() {

	echo '<h4>' . __( 'Recommended video sizes', 'youtubeprofile' ) . '</h4>';

    echo '<ul style="list-style: inside square;">
			<li>480x385</li>
			<li>560x340</li>
			<li>640x385</li>
			<li>853x505</li>
		</ul>';

}

?>