<?php
/*
 * Plugin Name: Youtube Profile Field
 * Plugin URI: http://jayj.dk/template/plugins/youtube-profile-field/
 * Description: Adds an Youtube username field to the user profile page and allow you to show your videos on your website.
 * Author: Jayjdk
 * Author URI: http://jayj.dk
 * Version: 2.1
 * License: GPLv2 or later
 */
 
/*
This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

// Load translation
load_plugin_textdomain( 'youtubeprofile', false, 'youtube-profile-field/langs' ); 

if ( is_admin() )
	include_once dirname( __FILE__ ) . '/admin.php';


/*
 * Get the video
 *
 * @param	array	$options  
 * @param	int		$userid		ID of the user where the videos should be retrieved from
 * @since 2.1
 */
function ypf_get_video( $options, $userid ) {

	// Get options
	$count = ( $options[0] ) ? $options[0] : $options['count'];
	
	$heading_start = $options['headingStart'];
	$heading_end = $options['headingEnd'];

	// Get the width from the Media settings or the theme width
	$default_width = ( get_option( 'embed_size_w' ) ) ? get_option( 'embed_size_w' ) : (int) $GLOBALS['content_width'];

	$width = ( $options['width'] ) ? $options['width'] : $default_width;
	$height = ( $options['height'] ) ? $options['height'] : get_option( 'embed_size_h' );
	
	// Get the username
	$username = get_the_author_meta( 'youtube', $userid ); 

	// Get the videos
	include_once( ABSPATH . WPINC . '/feed.php' );

	$rss = fetch_feed( "http://gdata.youtube.com/feeds/base/users/$username/uploads" );

	// Checks that the object is created correctly 
	if ( ! is_wp_error( $rss ) ) :
   		$maxitems = $rss->get_item_quantity( intval( $count ) );
		$rss_items = $rss->get_items( 0, $maxitems );
	endif;

	if ( $maxitems != 0 ) :

		ob_start();

		foreach ( $rss_items as $item ) : 

			// Get video ID - why don't Youtube give us this?
			$url = $item->get_permalink();

			if ( preg_match('![?&]{1}v=([^&]+)!', $url . '&', $m ))
    			$id = $m[1];

			// If using the old embed code
			if ( $options['embed_code'] == 1 ) { ?>

                <div class="youtube-video">
                	<?php if ( ! empty( $heading_start ) ) { ?>
						<?php echo html_entity_decode( $heading_start ); ?>
                            <a href="<?php echo $item->get_permalink(); ?>"><?php echo $item->get_title(); ?></a>
                        <?php echo html_entity_decode( $heading_end ); ?>
                    <?php } ?>

                    <object type="application/x-shockwave-flash" width="<?php echo intval( $width ); ?>" height="<?php echo intval( $height ); ?>" data="http://www.youtube.com/v/<?php echo esc_attr( $id ); ?>&amp;fs=1">
                    	<param name="movie" value="http://www.youtube.com/v/<?php echo esc_attr( $id ); ?>&amp;fs=1" />
                    	<param name="allowFullScreen" value="true" />
                    	<param name="wmode" value="transparent" />
                    </object>
                </div>

			<?php
            } else { ?>

                <div class="youtube-video">
                	<?php if ( ! empty( $heading_start ) ) { ?>
						<?php echo html_entity_decode( $heading_start ); ?>
                            <a href="<?php echo $item->get_permalink(); ?>"><?php echo $item->get_title(); ?></a>
                        <?php echo html_entity_decode( $heading_end ); ?>
                    <?php } ?>

                    <iframe title="<?php echo esc_attr( $item->get_title() ); ?>" width="<?php echo intval( $width ); ?>" height="<?php echo intval( $height ); ?>" src="http://www.youtube.com/embed/<?php echo esc_attr( $id ); ?>?rel=0&amp;hd=1" frameborder="0" allowfullscreen></iframe>
                </div>

			<?php
			}

		endforeach;

		return ob_get_clean();

	endif; // $maxitems

	return;
}

/**
 * Show the video
 *
 * @param	int		$count	Number of videos
 * @param	int		$userid		ID of the user where the videos should be retrieved from
 * @since 2.0.2
 */
function ypf_show_video( $count = '', $userid = 1 ) {

	/* Get options */
	$default_options = get_option( 'ypf_options' );
	$options = wp_parse_args( func_get_args(), $default_options );

	return ypf_get_video( $options, $userid );
}

/**
 * The [youtube-user] shortcode
 *
 * @since 1.0
 */
function ypf_youtube_user_shortcode( $atts ) {

	extract( shortcode_atts(array(
		'display' => '1',
		'id' => '',
	), $atts) );

	// Get options
	$options = get_option( 'ypf_options' );
	$embed = $options['embed_code'];
	
	$default_width = ( get_option( 'embed_size_w' ) ) ? get_option( 'embed_size_w' ) : (int) $GLOBALS['content_width'];

	$width = ( $options['width'] ) ? $options['width'] : $default_width;
	$height = ( $options['height'] ) ? $options['height'] : get_option( 'embed_size_h' );

	if ( $id ) : 
	
		ob_start();
		
		// Use old object embed code
		if ( $options['embed_code'] == 1 ) { ?>

			<div class="youtube-video">
				<object type="application/x-shockwave-flash" width="<?php echo intval( $width ); ?>" height="<?php echo intval( $height ); ?>" data="http://www.youtube.com/v/<?php echo esc_attr( $id ); ?>&amp;fs=1">
					<param name="movie" value="http://www.youtube.com/v/<?php echo esc_attr( $id ); ?>&amp;fs=1" />
					<param name="allowFullScreen" value="true" />
					<param name="wmode" value="transparent" />
				</object>
			</div>

		<?php
		} else { ?>

			<div class="youtube-video">
				<iframe width="<?php echo intval( $width ); ?>" height="<?php echo intval( $height ); ?>" src="http://www.youtube.com/embed/<?php echo esc_attr( $id ); ?>?rel=0&amp;hd=1" frameborder="0" allowfullscreen></iframe>
			</div>

		<?php
		}

		return ob_get_clean();

	// Latest videos
	else :

		return ypf_show_video( $display, get_the_author_meta( 'ID' ) );

	endif; // $id;
}

add_shortcode( 'youtube-user', 'ypf_youtube_user_shortcode' );

/*
 * Create the Youtube profile field
 */
function yfp_youtube_field( $contactmethods ) {
		$contactmethods['youtube'] = 'Youtube username';
		return $contactmethods;
}

add_filter( 'user_contactmethods', 'yfp_youtube_field' );

/**
 * Add a link to the settings
 */
function ypf_plugin_action_links( $links, $file ) {
    static $this_plugin;

    if ( ! $this_plugin )
        $this_plugin = plugin_basename( __FILE__ );
		
    if ( $file == $this_plugin ) {
        $settings_link = '<a href="' . admin_url( 'options-general.php?page=youtube-profile-field' ) . '">Settings</a>';
        array_unshift( $links, $settings_link );
    }

    return $links;
}

add_filter( 'plugin_action_links', 'ypf_plugin_action_links', 10, 2) ;

/**
 * Install hook
 */
register_activation_hook( __FILE__, 'ypf_install' );

function ypf_install() {

	// Deactivate the plugin if using older than 3.1
    if ( version_compare( get_bloginfo( 'version' ), '3.1', '<' ) ) {
        deactivate_plugins( basename( __FILE__ ) );
    }

	// Default options
	$ypf_options = array(
		'count' => '1',
  		'headingStart' => '&lt;h4&gt;',
  		'headingEnd' => '&lt;/h4&gt;',
  		'embed_code' => 0
	);

	update_option( 'ypf_options', $ypf_options );
}

?>